diff transform/TransformFactory.h @ 60:3086ff194ea0

* More structural work on feature extraction plugin C <-> C++ adapter * Allow use of LADSPA/DSSI plugins with control outputs as feature extraction plugins (DSSI with MIDI output still to come) * Reorder labels on spectrogram status box * Minor tweaks in doc etc.
author Chris Cannam
date Mon, 27 Mar 2006 15:03:02 +0000
parents 7439f1696314
children ba405e5e69d3
line wrap: on
line diff
--- a/transform/TransformFactory.h	Fri Mar 24 18:15:50 2006 +0000
+++ b/transform/TransformFactory.h	Mon Mar 27 15:03:02 2006 +0000
@@ -33,14 +33,20 @@
     // within the application.  The description is intended to be
     // human readable.  In principle it doesn't have to be unique, but
     // the factory will add suffixes to ensure that it is, all the
     // same (just to avoid user confusion).
 
     struct TransformDesc {
         TransformDesc() { }
-	TransformDesc(TransformName _name, QString _description, bool _configurable) :
-	    name(_name), description(_description), configurable(_configurable) { }
+	TransformDesc(TransformName _name, QString _description,
+                      QString _friendlyName, QString _maker,
+                      bool _configurable) :
+	    name(_name), description(_description), friendlyName(_friendlyName),
+            maker(_maker), configurable(_configurable) { }
 	TransformName name;
 	QString description;
+        QString friendlyName;
+        QString maker;
         bool configurable;
     };
     typedef std::vector<TransformDesc> TransformList;
@@ -116,6 +122,8 @@
     TransformDescriptionMap m_transforms;
 
     void populateTransforms();
+    void populateFeatureExtractionPlugins(TransformDescriptionMap &);
+    void populateRealTimePlugins(TransformDescriptionMap &);
 
     static TransformFactory *m_instance;
 };
@@ -33,14 +33,20 @@
     // human readable.  In principle it doesn't have to be unique, but
     // the factory will add suffixes to ensure that it is, all the
-    // same (just to avoid user confusion).
+    // same (just to avoid user confusion).  The friendly name is a
+    // shorter version of the description.
 
     struct TransformDesc {